"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var format_duration_1 = require("../format-duration");
var SECONDS_IN_HOUR = 3600;
var SECONDS_IN_MINUTE = 60;
describe('format should work correctly', function () {
    it('should format 0 seconds to 00:00', function () {
        expect(format_duration_1.formatDuration(0)).toBe('00:00');
    });
    it('should format positive durations with hours, minutes, and seconds', function () {
        expect(format_duration_1.formatDuration(3661, 'HH:mm:ss')).toBe('01:01:01');
        expect(format_duration_1.formatDuration(3600, 'HH:mm:ss')).toBe('01:00:00');
        expect(format_duration_1.formatDuration(61, 'HH:mm:ss')).toBe('00:01:01');
        expect(format_duration_1.formatDuration(60, 'HH:mm:ss')).toBe('00:01:00');
        expect(format_duration_1.formatDuration(1, 'HH:mm:ss')).toBe('00:00:01');
        expect(format_duration_1.formatDuration(3601, 'HH:mm:ss')).toBe('01:00:01');
        expect(format_duration_1.formatDuration(3660, 'HH:mm:ss')).toBe('01:01:00');
    });
    it('should format positive durations with hours and minutes', function () {
        expect(format_duration_1.formatDuration(3661, 'HH:mm')).toBe('01:01');
        expect(format_duration_1.formatDuration(3600, 'HH:mm')).toBe('01:00');
        expect(format_duration_1.formatDuration(61, 'HH:mm')).toBe('00:01');
        expect(format_duration_1.formatDuration(60, 'HH:mm')).toBe('00:01');
        expect(format_duration_1.formatDuration(1, 'HH:mm')).toBe('00:00');
        expect(format_duration_1.formatDuration(3601, 'HH:mm')).toBe('01:00');
        expect(format_duration_1.formatDuration(3660, 'HH:mm')).toBe('01:01');
    });
    it('should format negative durations with a minus sign', function () {
        expect(format_duration_1.formatDuration(-3661, 'HH:mm:ss')).toBe('-01:01:01');
        expect(format_duration_1.formatDuration(-3661, 'HH:mm')).toBe('-01:01');
        expect(format_duration_1.formatDuration(-3600, 'HH:mm:ss')).toBe('-01:00:00');
        expect(format_duration_1.formatDuration(-61, 'HH:mm:ss')).toBe('-00:01:01');
        expect(format_duration_1.formatDuration(-60, 'HH:mm:ss')).toBe('-00:01:00');
        expect(format_duration_1.formatDuration(-1, 'HH:mm:ss')).toBe('-00:00:01');
        expect(format_duration_1.formatDuration(-3601, 'HH:mm:ss')).toBe('-01:00:01');
        expect(format_duration_1.formatDuration(-3660, 'HH:mm:ss')).toBe('-01:01:00');
    });
    it('should return "00:00" if seconds is not a number', function () {
        // @ts-ignore - testing invalid input
        expect(format_duration_1.formatDuration(undefined)).toBe('00:00');
        // @ts-ignore - testing invalid input
        expect(format_duration_1.formatDuration(null)).toBe('00:00');
        // @ts-ignore - testing invalid input
        expect(format_duration_1.formatDuration('')).toBe('00:00');
        expect(format_duration_1.formatDuration(NaN)).toBe('00:00');
        expect(format_duration_1.formatDuration({})).toBe('00:00');
    });
    it('Converts duration to right format', function () {
        var testCases = [
            {
                durationInSeconds: 24 * SECONDS_IN_HOUR,
                format: 'HH:mm',
                expectedResult: '24:00',
            },
            {
                durationInSeconds: 8 * SECONDS_IN_HOUR + 23 * SECONDS_IN_MINUTE + 12,
                format: 'HH:mm',
                expectedResult: '08:23',
            },
            {
                durationInSeconds: 2 * SECONDS_IN_HOUR + 2 * SECONDS_IN_MINUTE + 2,
                format: 'HH:mm',
                expectedResult: '02:02',
            },
            {
                durationInSeconds: 2 * SECONDS_IN_HOUR + 3 * SECONDS_IN_MINUTE + 4,
                format: 'HH:mm:ss',
                expectedResult: '02:03:04',
            },
            {
                durationInSeconds: 763 * SECONDS_IN_HOUR + 3 * SECONDS_IN_MINUTE + 4,
                format: 'HH:mm',
                expectedResult: '763:03',
            },
            {
                durationInSeconds: 763 * SECONDS_IN_HOUR + 3 * SECONDS_IN_MINUTE + 4,
                format: 'HH:mm:ss',
                expectedResult: '763:03:04',
            },
            {
                durationInSeconds: -(24 * SECONDS_IN_HOUR),
                format: 'HH:mm',
                expectedResult: '-24:00',
            },
            {
                durationInSeconds: -(8 * SECONDS_IN_HOUR + 23 * SECONDS_IN_MINUTE + 12),
                format: 'HH:mm',
                expectedResult: '-08:23',
            },
            {
                durationInSeconds: -(2 * SECONDS_IN_HOUR + 2 * SECONDS_IN_MINUTE + 2),
                format: 'HH:mm',
                expectedResult: '-02:02',
            },
            {
                durationInSeconds: -(2 * SECONDS_IN_HOUR + 3 * SECONDS_IN_MINUTE + 4),
                format: 'HH:mm:ss',
                expectedResult: '-02:03:04',
            },
            {
                durationInSeconds: -(763 * SECONDS_IN_HOUR + 3 * SECONDS_IN_MINUTE + 4),
                format: 'HH:mm',
                expectedResult: '-763:03',
            },
            {
                durationInSeconds: -(763 * SECONDS_IN_HOUR + 3 * SECONDS_IN_MINUTE + 4),
                format: 'HH:mm:ss',
                expectedResult: '-763:03:04',
            },
            {
                durationInSeconds: 0,
                format: 'HH:mm:ss',
                expectedResult: '00:00:00',
            },
            {
                durationInSeconds: 34,
                format: 'HH:mm:ss',
                expectedResult: '00:00:34',
            },
            {
                durationInSeconds: 270,
                format: 'HH:mm:ss',
                expectedResult: '00:04:30',
            },
        ];
        testCases.forEach(function (_a) {
            var durationInSeconds = _a.durationInSeconds, format = _a.format, expectedResult = _a.expectedResult;
            var actualResult = format_duration_1.formatDuration(durationInSeconds, format);
            expect(actualResult).toBe(expectedResult);
        });
    });
});
//# sourceMappingURL=format-duration.test.js.map