"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.formatCurrency = void 0;
var tslib_1 = require("tslib");
var accounting_1 = tslib_1.__importDefault(require("accounting"));
var settings_1 = require("../common/constants/settings");
var number_format_1 = require("../common/models/types/number-format");
var getSymbolFormatAndFractionSize = function (currency) {
    var currencies = settings_1.getCurrencies();
    var currencyObject = currencies.find(function (x) { return x.id === currency; }) || {
        id: 'EUR',
        name: 'Euro',
        fractionSize: 2,
        symbol: {
            grapheme: '€',
            template: '$1',
            rtl: false,
        },
        uniqSymbol: {
            grapheme: '€',
            template: '$1',
            rtl: false,
        },
    };
    var symbol = currencyObject.symbol, fractionSize = currencyObject.fractionSize;
    if (symbol) {
        var grapheme = symbol.grapheme, template = symbol.template;
        var format = template.replace('$', '%s').replace('1', '%v');
        return { symbol: grapheme, format: format, fractionSize: fractionSize };
    }
    return { symbol: currencyObject.id, fractionSize: fractionSize };
};
function formatCurrency(input, currency, numberFormat) {
    var _a;
    if (currency === void 0) { currency = 'EUR'; }
    if (numberFormat === void 0) { numberFormat = number_format_1.NumberFormat.Dot; }
    var result = getSymbolFormatAndFractionSize(currency);
    var map = (_a = {},
        _a[number_format_1.NumberFormat.Dot] = function () {
            return accounting_1.default.formatMoney(input, tslib_1.__assign(tslib_1.__assign({}, result), { decimal: ',', thousand: '.' }));
        },
        _a[number_format_1.NumberFormat.Comma] = function () {
            return accounting_1.default.formatMoney(input, tslib_1.__assign(tslib_1.__assign({}, result), { decimal: '.', thousand: ',' }));
        },
        _a[number_format_1.NumberFormat.Space] = function () {
            return accounting_1.default.formatMoney(input, tslib_1.__assign(tslib_1.__assign({}, result), { decimal: ',', thousand: ' ' }));
        },
        _a[number_format_1.NumberFormat.Apostrophe] = function () {
            return accounting_1.default.formatMoney(input, tslib_1.__assign(tslib_1.__assign({}, result), { decimal: ',', thousand: "'" }));
        },
        _a);
    return map[numberFormat]();
}
exports.formatCurrency = formatCurrency;
//# sourceMappingURL=format-currency.js.map