"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var calculate_time_1 = require("../calculate-time");
var date_1 = require("../../common/utils/date");
var SECONDS_IN_MINUTE = 60;
var MINUTES_IN_HOUR = 60;
var SECONDS_IN_HOUR = SECONDS_IN_MINUTE * MINUTES_IN_HOUR;
describe('Day entry formatting', function () {
    it('should calculate start/end/duration combination correctly', function () {
        var getDateFrom00 = function (hours, minutes) {
            if (hours === void 0) { hours = 0; }
            if (minutes === void 0) { minutes = 0; }
            return new date_1.TcDate()
                .startOf('day')
                .add(hours, 'hour')
                .add(minutes, 'minute');
        };
        var testConditions = [
            {
                input: { start: '12', end: undefined, duration: undefined },
                expected: { start: getDateFrom00(12), end: null, duration: null },
            },
            {
                input: { start: undefined, end: '17', duration: undefined },
                expected: { start: null, end: getDateFrom00(17), duration: null },
            },
            {
                input: { start: undefined, end: undefined, duration: '5' },
                expected: { start: null, end: null, duration: 5 * SECONDS_IN_HOUR },
            },
            {
                input: { start: '12:30', end: '17:00', duration: undefined },
                expected: {
                    start: getDateFrom00(12, 30),
                    end: getDateFrom00(17),
                    duration: 4.5 * SECONDS_IN_HOUR,
                },
            },
            {
                input: { start: '17:00', end: '12:00', duration: undefined },
                expected: {
                    start: getDateFrom00(17),
                    end: getDateFrom00(24 + 12),
                    duration: 19 * SECONDS_IN_HOUR,
                },
            },
            {
                input: { start: '12:00', end: undefined, duration: '5' },
                expected: {
                    start: getDateFrom00(12),
                    end: getDateFrom00(17),
                    duration: 5 * SECONDS_IN_HOUR,
                },
            },
            {
                input: { start: undefined, end: '17:00', duration: '5' },
                expected: {
                    start: getDateFrom00(12),
                    end: getDateFrom00(17),
                    duration: 5 * SECONDS_IN_HOUR,
                },
            },
            {
                input: { start: '03:00', end: '03:01', duration: undefined },
                expected: {
                    start: getDateFrom00(3),
                    end: getDateFrom00(3, 1),
                    duration: 1 * SECONDS_IN_MINUTE,
                },
            },
            {
                input: { start: '03:00', end: '03:10', duration: undefined },
                expected: {
                    start: getDateFrom00(3),
                    end: getDateFrom00(3, 10),
                    duration: 10 * SECONDS_IN_MINUTE,
                },
            },
        ];
        testConditions.forEach(function (_a) {
            var _b, _c, _d, _e;
            var input = _a.input, expected = _a.expected;
            var actual = calculate_time_1.calculateTime(new Date(), input.start, input.end, input.duration);
            expect((_b = actual.start) === null || _b === void 0 ? void 0 : _b.toUTCString()).toEqual((_c = expected.start) === null || _c === void 0 ? void 0 : _c.toDate().toUTCString());
            expect((_d = actual.end) === null || _d === void 0 ? void 0 : _d.toUTCString()).toEqual((_e = expected.end) === null || _e === void 0 ? void 0 : _e.toDate().toUTCString());
            expect(actual.duration).toBe(expected.duration);
        });
    });
});
//# sourceMappingURL=calculate-time.test.js.map