export function getTimezones() {
    return [
        {
            id: 'Dateline Standard Time',
            abbr: 'DST',
            offset: -12,
            isdst: false,
            name: '(UTC-12:00) International Date Line West',
            utc: ['Etc/GMT+12'],
        },
        {
            id: 'UTC-11',
            abbr: 'U',
            offset: -11,
            isdst: false,
            name: '(UTC-11:00) Coordinated Universal Time-11',
            utc: [
                'Etc/GMT+11',
                'Pacific/Midway',
                'Pacific/Niue',
                'Pacific/Pago_Pago',
            ],
        },
        {
            id: 'Hawaiian Standard Time',
            abbr: 'HST',
            offset: -10,
            isdst: false,
            name: '(UTC-10:00) Hawaii',
            utc: [
                'Etc/GMT+10',
                'Pacific/Honolulu',
                'Pacific/Johnston',
                'Pacific/Rarotonga',
                'Pacific/Tahiti',
            ],
        },
        {
            id: 'Alaskan Standard Time',
            abbr: 'AKDT',
            offset: -8,
            isdst: true,
            name: '(UTC-09:00) Alaska',
            utc: [
                'America/Anchorage',
                'America/Juneau',
                'America/Nome',
                'America/Sitka',
                'America/Yakutat',
            ],
        },
        {
            id: 'Pacific Standard Time (Mexico)',
            abbr: 'PDT',
            offset: -7,
            isdst: true,
            name: '(UTC-08:00) Baja California',
            utc: ['America/Santa_Isabel'],
        },
        {
            id: 'Pacific Daylight Time',
            abbr: 'PDT',
            offset: -7,
            isdst: true,
            name: '(UTC-07:00) Pacific Time (US & Canada)',
            utc: [
                'America/Dawson',
                'America/Los_Angeles',
                'America/Tijuana',
                'America/Vancouver',
                'America/Whitehorse',
            ],
        },
        {
            id: 'Pacific Standard Time',
            abbr: 'PST',
            offset: -8,
            isdst: false,
            name: '(UTC-08:00) Pacific Time (US & Canada)',
            utc: [
                'America/Dawson',
                'America/Los_Angeles',
                'America/Tijuana',
                'America/Vancouver',
                'America/Whitehorse',
                'PST8PDT',
            ],
        },
        {
            id: 'US Mountain Standard Time',
            abbr: 'UMST',
            offset: -7,
            isdst: false,
            name: '(UTC-07:00) Arizona',
            utc: [
                'America/Creston',
                'America/Dawson_Creek',
                'America/Hermosillo',
                'America/Phoenix',
                'Etc/GMT+7',
            ],
        },
        {
            id: 'Mountain Standard Time (Mexico)',
            abbr: 'MDT',
            offset: -6,
            isdst: true,
            name: '(UTC-07:00) Chihuahua, La Paz, Mazatlan',
            utc: ['America/Chihuahua', 'America/Mazatlan'],
        },
        {
            id: 'Mountain Standard Time',
            abbr: 'MDT',
            offset: -6,
            isdst: true,
            name: '(UTC-07:00) Mountain Time (US & Canada)',
            utc: [
                'America/Boise',
                'America/Cambridge_Bay',
                'America/Denver',
                'America/Edmonton',
                'America/Inuvik',
                'America/Ojinaga',
                'America/Yellowknife',
                'MST7MDT',
            ],
        },
        {
            id: 'Central America Standard Time',
            abbr: 'CAST',
            offset: -6,
            isdst: false,
            name: '(UTC-06:00) Central America',
            utc: [
                'America/Belize',
                'America/Costa_Rica',
                'America/El_Salvador',
                'America/Guatemala',
                'America/Managua',
                'America/Tegucigalpa',
                'Etc/GMT+6',
                'Pacific/Galapagos',
            ],
        },
        {
            id: 'Central Standard Time',
            abbr: 'CDT',
            offset: -5,
            isdst: true,
            name: '(UTC-06:00) Central Time (US & Canada)',
            utc: [
                'America/Chicago',
                'America/Indiana/Knox',
                'America/Indiana/Tell_City',
                'America/Matamoros',
                'America/Menominee',
                'America/North_Dakota/Beulah',
                'America/North_Dakota/Center',
                'America/North_Dakota/New_Salem',
                'America/Rainy_River',
                'America/Rankin_Inlet',
                'America/Resolute',
                'America/Winnipeg',
                'CST6CDT',
            ],
        },
        {
            id: 'Central Standard Time (Mexico)',
            abbr: 'CDT',
            offset: -5,
            isdst: true,
            name: '(UTC-06:00) Guadalajara, Mexico City, Monterrey',
            utc: [
                'America/Bahia_Banderas',
                'America/Cancun',
                'America/Merida',
                'America/Mexico_City',
                'America/Monterrey',
            ],
        },
        {
            id: 'Canada Central Standard Time',
            abbr: 'CCST',
            offset: -6,
            isdst: false,
            name: '(UTC-06:00) Saskatchewan',
            utc: ['America/Regina', 'America/Swift_Current'],
        },
        {
            id: 'SA Pacific Standard Time',
            abbr: 'SPST',
            offset: -5,
            isdst: false,
            name: '(UTC-05:00) Bogota, Lima, Quito',
            utc: [
                'America/Bogota',
                'America/Cayman',
                'America/Coral_Harbour',
                'America/Eirunepe',
                'America/Guayaquil',
                'America/Jamaica',
                'America/Lima',
                'America/Panama',
                'America/Rio_Branco',
                'Etc/GMT+5',
            ],
        },
        {
            id: 'Eastern Standard Time',
            abbr: 'EDT',
            offset: -4,
            isdst: true,
            name: '(UTC-05:00) Eastern Time (US & Canada)',
            utc: [
                'America/Detroit',
                'America/Havana',
                'America/Indiana/Petersburg',
                'America/Indiana/Vincennes',
                'America/Indiana/Winamac',
                'America/Iqaluit',
                'America/Kentucky/Monticello',
                'America/Louisville',
                'America/Montreal',
                'America/Nassau',
                'America/New_York',
                'America/Nipigon',
                'America/Pangnirtung',
                'America/Port-au-Prince',
                'America/Thunder_Bay',
                'America/Toronto',
                'EST5EDT',
            ],
        },
        {
            id: 'US Eastern Standard Time',
            abbr: 'UEDT',
            offset: -4,
            isdst: true,
            name: '(UTC-05:00) Indiana (East)',
            utc: [
                'America/Indiana/Marengo',
                'America/Indiana/Vevay',
                'America/Indianapolis',
            ],
        },
        {
            id: 'Venezuela Standard Time',
            abbr: 'VST',
            offset: -4.5,
            isdst: false,
            name: '(UTC-04:30) Caracas',
            utc: ['America/Caracas'],
        },
        {
            id: 'Paraguay Standard Time',
            abbr: 'PYT',
            offset: -4,
            isdst: false,
            name: '(UTC-04:00) Asuncion',
            utc: ['America/Asuncion'],
        },
        {
            id: 'Atlantic Standard Time',
            abbr: 'ADT',
            offset: -3,
            isdst: true,
            name: '(UTC-04:00) Atlantic Time (Canada)',
            utc: [
                'America/Glace_Bay',
                'America/Goose_Bay',
                'America/Halifax',
                'America/Moncton',
                'America/Thule',
                'Atlantic/Bermuda',
            ],
        },
        {
            id: 'Central Brazilian Standard Time',
            abbr: 'CBST',
            offset: -4,
            isdst: false,
            name: '(UTC-04:00) Cuiaba',
            utc: ['America/Campo_Grande', 'America/Cuiaba'],
        },
        {
            id: 'SA Western Standard Time',
            abbr: 'SWST',
            offset: -4,
            isdst: false,
            name: '(UTC-04:00) Georgetown, La Paz, Manaus, San Juan',
            utc: [
                'America/Anguilla',
                'America/Antigua',
                'America/Aruba',
                'America/Barbados',
                'America/Blanc-Sablon',
                'America/Boa_Vista',
                'America/Curacao',
                'America/Dominica',
                'America/Grand_Turk',
                'America/Grenada',
                'America/Guadeloupe',
                'America/Guyana',
                'America/Kralendijk',
                'America/La_Paz',
                'America/Lower_Princes',
                'America/Manaus',
                'America/Marigot',
                'America/Martinique',
                'America/Montserrat',
                'America/Port_of_Spain',
                'America/Porto_Velho',
                'America/Puerto_Rico',
                'America/Santo_Domingo',
                'America/St_Barthelemy',
                'America/St_Kitts',
                'America/St_Lucia',
                'America/St_Thomas',
                'America/St_Vincent',
                'America/Tortola',
                'Etc/GMT+4',
            ],
        },
        {
            id: 'Pacific SA Standard Time',
            abbr: 'PSST',
            offset: -4,
            isdst: false,
            name: '(UTC-04:00) Santiago',
            utc: ['America/Santiago', 'Antarctica/Palmer'],
        },
        {
            id: 'Newfoundland Standard Time',
            abbr: 'NDT',
            offset: -2.5,
            isdst: true,
            name: '(UTC-03:30) Newfoundland',
            utc: ['America/St_Johns'],
        },
        {
            id: 'E. South America Standard Time',
            abbr: 'ESAST',
            offset: -3,
            isdst: false,
            name: '(UTC-03:00) Brasilia',
            utc: ['America/Sao_Paulo'],
        },
        {
            id: 'Argentina Standard Time',
            abbr: 'AST',
            offset: -3,
            isdst: false,
            name: '(UTC-03:00) Buenos Aires',
            utc: [
                'America/Argentina/La_Rioja',
                'America/Argentina/Rio_Gallegos',
                'America/Argentina/Salta',
                'America/Argentina/San_Juan',
                'America/Argentina/San_Luis',
                'America/Argentina/Tucuman',
                'America/Argentina/Ushuaia',
                'America/Buenos_Aires',
                'America/Catamarca',
                'America/Cordoba',
                'America/Jujuy',
                'America/Mendoza',
            ],
        },
        {
            id: 'SA Eastern Standard Time',
            abbr: 'SEST',
            offset: -3,
            isdst: false,
            name: '(UTC-03:00) Cayenne, Fortaleza',
            utc: [
                'America/Araguaina',
                'America/Belem',
                'America/Cayenne',
                'America/Fortaleza',
                'America/Maceio',
                'America/Paramaribo',
                'America/Recife',
                'America/Santarem',
                'Antarctica/Rothera',
                'Atlantic/Stanley',
                'Etc/GMT+3',
            ],
        },
        {
            id: 'Greenland Standard Time',
            abbr: 'GDT',
            offset: -3,
            isdst: true,
            name: '(UTC-03:00) Greenland',
            utc: ['America/Godthab'],
        },
        {
            id: 'Montevideo Standard Time',
            abbr: 'MST',
            offset: -3,
            isdst: false,
            name: '(UTC-03:00) Montevideo',
            utc: ['America/Montevideo'],
        },
        {
            id: 'Bahia Standard Time',
            abbr: 'BST',
            offset: -3,
            isdst: false,
            name: '(UTC-03:00) Salvador',
            utc: ['America/Bahia'],
        },
        {
            id: 'UTC-02',
            abbr: 'U',
            offset: -2,
            isdst: false,
            name: '(UTC-02:00) Coordinated Universal Time-02',
            utc: ['America/Noronha', 'Atlantic/South_Georgia', 'Etc/GMT+2'],
        },
        {
            id: 'Mid-Atlantic Standard Time',
            abbr: 'MDT',
            offset: -1,
            isdst: true,
            name: '(UTC-02:00) Mid-Atlantic - Old',
            utc: [],
        },
        {
            id: 'Azores Standard Time',
            abbr: 'ADT',
            offset: 0,
            isdst: true,
            name: '(UTC-01:00) Azores',
            utc: ['America/Scoresbysund', 'Atlantic/Azores'],
        },
        {
            id: 'Cape Verde Standard Time',
            abbr: 'CVST',
            offset: -1,
            isdst: false,
            name: '(UTC-01:00) Cape Verde Is.',
            utc: ['Atlantic/Cape_Verde', 'Etc/GMT+1'],
        },
        {
            id: 'Morocco Standard Time',
            abbr: 'MDT',
            offset: 1,
            isdst: true,
            name: '(UTC) Casablanca',
            utc: ['Africa/Casablanca', 'Africa/El_Aaiun'],
        },
        {
            id: 'utc',
            abbr: 'utc',
            offset: 0,
            isdst: false,
            name: '(UTC) Coordinated Universal Time',
            utc: ['America/Danmarkshavn', 'Etc/GMT'],
        },
        {
            id: 'Greenwich Mean Time',
            abbr: 'GMT',
            offset: 0,
            isdst: false,
            name: '(UTC) Edinburgh, London',
            utc: [
                'Europe/Isle_of_Man',
                'Europe/Guernsey',
                'Europe/Jersey',
                'Europe/London',
            ],
        },
        {
            id: 'British Summer Time',
            abbr: 'BST',
            offset: 1,
            isdst: true,
            name: '(UTC+01:00) Edinburgh, London',
            utc: [
                'Europe/Isle_of_Man',
                'Europe/Guernsey',
                'Europe/Jersey',
                'Europe/London',
            ],
        },
        {
            id: 'GMT Standard Time',
            abbr: 'GDT',
            offset: 1,
            isdst: true,
            name: '(UTC) Dublin, Lisbon',
            utc: [
                'Atlantic/Canary',
                'Atlantic/Faeroe',
                'Atlantic/Madeira',
                'Europe/Dublin',
                'Europe/Lisbon',
            ],
        },
        {
            id: 'Greenwich Standard Time',
            abbr: 'GST',
            offset: 0,
            isdst: false,
            name: '(UTC) Monrovia, Reykjavik',
            utc: [
                'Africa/Abidjan',
                'Africa/Accra',
                'Africa/Bamako',
                'Africa/Banjul',
                'Africa/Bissau',
                'Africa/Conakry',
                'Africa/Dakar',
                'Africa/Freetown',
                'Africa/Lome',
                'Africa/Monrovia',
                'Africa/Nouakchott',
                'Africa/Ouagadougou',
                'Africa/Sao_Tome',
                'Atlantic/Reykjavik',
                'Atlantic/St_Helena',
            ],
        },
        {
            id: 'W. Europe Standard Time',
            abbr: 'WEDT',
            offset: 2,
            isdst: true,
            name: '(UTC+01:00) Amsterdam, Berlin, Bern, Rome, Stockholm, Vienna',
            utc: [
                'Arctic/Longyearbyen',
                'Europe/Amsterdam',
                'Europe/Andorra',
                'Europe/Berlin',
                'Europe/Busingen',
                'Europe/Gibraltar',
                'Europe/Luxembourg',
                'Europe/Malta',
                'Europe/Monaco',
                'Europe/Oslo',
                'Europe/Rome',
                'Europe/San_Marino',
                'Europe/Stockholm',
                'Europe/Vaduz',
                'Europe/Vatican',
                'Europe/Vienna',
                'Europe/Zurich',
            ],
        },
        {
            id: 'Central Europe Standard Time',
            abbr: 'CEDT',
            offset: 2,
            isdst: true,
            name: '(UTC+01:00) Belgrade, Bratislava, Budapest, Ljubljana, Prague',
            utc: [
                'Europe/Belgrade',
                'Europe/Bratislava',
                'Europe/Budapest',
                'Europe/Ljubljana',
                'Europe/Podgorica',
                'Europe/Prague',
                'Europe/Tirane',
            ],
        },
        {
            id: 'Romance Standard Time',
            abbr: 'RDT',
            offset: 2,
            isdst: true,
            name: '(UTC+01:00) Brussels, Copenhagen, Madrid, Paris',
            utc: [
                'Africa/Ceuta',
                'Europe/Brussels',
                'Europe/Copenhagen',
                'Europe/Madrid',
                'Europe/Paris',
            ],
        },
        {
            id: 'Central European Standard Time',
            abbr: 'CEDT',
            offset: 2,
            isdst: true,
            name: '(UTC+01:00) Sarajevo, Skopje, Warsaw, Zagreb',
            utc: [
                'Europe/Sarajevo',
                'Europe/Skopje',
                'Europe/Warsaw',
                'Europe/Zagreb',
            ],
        },
        {
            id: 'W. Central Africa Standard Time',
            abbr: 'WCAST',
            offset: 1,
            isdst: false,
            name: '(UTC+01:00) West Central Africa',
            utc: [
                'Africa/Algiers',
                'Africa/Bangui',
                'Africa/Brazzaville',
                'Africa/Douala',
                'Africa/Kinshasa',
                'Africa/Lagos',
                'Africa/Libreville',
                'Africa/Luanda',
                'Africa/Malabo',
                'Africa/Ndjamena',
                'Africa/Niamey',
                'Africa/Porto-Novo',
                'Africa/Tunis',
                'Etc/GMT-1',
            ],
        },
        {
            id: 'Namibia Standard Time',
            abbr: 'NST',
            offset: 1,
            isdst: false,
            name: '(UTC+01:00) Windhoek',
            utc: ['Africa/Windhoek'],
        },
        {
            id: 'GTB Standard Time',
            abbr: 'GDT',
            offset: 3,
            isdst: true,
            name: '(UTC+02:00) Athens, Bucharest',
            utc: [
                'Asia/Nicosia',
                'Europe/Athens',
                'Europe/Bucharest',
                'Europe/Chisinau',
            ],
        },
        {
            id: 'Middle East Standard Time',
            abbr: 'MEDT',
            offset: 3,
            isdst: true,
            name: '(UTC+02:00) Beirut',
            utc: ['Asia/Beirut'],
        },
        {
            id: 'Egypt Standard Time',
            abbr: 'EST',
            offset: 2,
            isdst: false,
            name: '(UTC+02:00) Cairo',
            utc: ['Africa/Cairo'],
        },
        {
            id: 'Syria Standard Time',
            abbr: 'SDT',
            offset: 3,
            isdst: true,
            name: '(UTC+02:00) Damascus',
            utc: ['Asia/Damascus'],
        },
        {
            id: 'E. Europe Standard Time',
            abbr: 'EEDT',
            offset: 3,
            isdst: true,
            name: '(UTC+02:00) E. Europe',
            utc: [
                'Asia/Nicosia',
                'Europe/Athens',
                'Europe/Bucharest',
                'Europe/Chisinau',
                'Europe/Helsinki',
                'Europe/Kiev',
                'Europe/Mariehamn',
                'Europe/Nicosia',
                'Europe/Riga',
                'Europe/Sofia',
                'Europe/Tallinn',
                'Europe/Uzhgorod',
                'Europe/Vilnius',
                'Europe/Zaporozhye',
            ],
        },
        {
            id: 'South Africa Standard Time',
            abbr: 'SAST',
            offset: 2,
            isdst: false,
            name: '(UTC+02:00) Harare, Pretoria',
            utc: [
                'Africa/Blantyre',
                'Africa/Bujumbura',
                'Africa/Gaborone',
                'Africa/Harare',
                'Africa/Johannesburg',
                'Africa/Kigali',
                'Africa/Lubumbashi',
                'Africa/Lusaka',
                'Africa/Maputo',
                'Africa/Maseru',
                'Africa/Mbabane',
                'Etc/GMT-2',
            ],
        },
        {
            id: 'FLE Standard Time',
            abbr: 'FDT',
            offset: 3,
            isdst: true,
            name: '(UTC+02:00) Helsinki, Kyiv, Riga, Sofia, Tallinn, Vilnius',
            utc: [
                'Europe/Helsinki',
                'Europe/Kiev',
                'Europe/Mariehamn',
                'Europe/Riga',
                'Europe/Sofia',
                'Europe/Tallinn',
                'Europe/Uzhgorod',
                'Europe/Vilnius',
                'Europe/Zaporozhye',
            ],
        },
        {
            id: 'Turkey Standard Time',
            abbr: 'TDT',
            offset: 3,
            isdst: false,
            name: '(UTC+03:00) Istanbul',
            utc: ['Europe/Istanbul'],
        },
        {
            id: 'Israel Standard Time',
            abbr: 'JDT',
            offset: 3,
            isdst: true,
            name: '(UTC+02:00) Jerusalem',
            utc: ['Asia/Jerusalem'],
        },
        {
            id: 'Libya Standard Time',
            abbr: 'LST',
            offset: 2,
            isdst: false,
            name: '(UTC+02:00) Tripoli',
            utc: ['Africa/Tripoli'],
        },
        {
            id: 'Jordan Standard Time',
            abbr: 'JST',
            offset: 3,
            isdst: false,
            name: '(UTC+03:00) Amman',
            utc: ['Asia/Amman'],
        },
        {
            id: 'Arabic Standard Time',
            abbr: 'AST',
            offset: 3,
            isdst: false,
            name: '(UTC+03:00) Baghdad',
            utc: ['Asia/Baghdad'],
        },
        {
            id: 'Kaliningrad Standard Time',
            abbr: 'KST',
            offset: 3,
            isdst: false,
            name: '(UTC+03:00) Kaliningrad, Minsk',
            utc: ['Europe/Kaliningrad', 'Europe/Minsk'],
        },
        {
            id: 'Arab Standard Time',
            abbr: 'AST',
            offset: 3,
            isdst: false,
            name: '(UTC+03:00) Kuwait, Riyadh',
            utc: [
                'Asia/Aden',
                'Asia/Bahrain',
                'Asia/Kuwait',
                'Asia/Qatar',
                'Asia/Riyadh',
            ],
        },
        {
            id: 'E. Africa Standard Time',
            abbr: 'EAST',
            offset: 3,
            isdst: false,
            name: '(UTC+03:00) Nairobi',
            utc: [
                'Africa/Addis_Ababa',
                'Africa/Asmera',
                'Africa/Dar_es_Salaam',
                'Africa/Djibouti',
                'Africa/Juba',
                'Africa/Kampala',
                'Africa/Khartoum',
                'Africa/Mogadishu',
                'Africa/Nairobi',
                'Antarctica/Syowa',
                'Etc/GMT-3',
                'Indian/Antananarivo',
                'Indian/Comoro',
                'Indian/Mayotte',
            ],
        },
        {
            id: 'Moscow Standard Time',
            abbr: 'MSK',
            offset: 3,
            isdst: false,
            name: '(UTC+03:00) Moscow, St. Petersburg, Volgograd',
            utc: [
                'Europe/Kirov',
                'Europe/Moscow',
                'Europe/Simferopol',
                'Europe/Volgograd',
            ],
        },
        {
            id: 'Samara Time',
            abbr: 'SAMT',
            offset: 4,
            isdst: false,
            name: '(UTC+04:00) Samara, Ulyanovsk, Saratov',
            utc: ['Europe/Astrakhan', 'Europe/Samara', 'Europe/Ulyanovsk'],
        },
        {
            id: 'Iran Standard Time',
            abbr: 'IDT',
            offset: 4.5,
            isdst: true,
            name: '(UTC+03:30) Tehran',
            utc: ['Asia/Tehran'],
        },
        {
            id: 'Arabian Standard Time',
            abbr: 'AST',
            offset: 4,
            isdst: false,
            name: '(UTC+04:00) Abu Dhabi, Muscat',
            utc: ['Asia/Dubai', 'Asia/Muscat', 'Etc/GMT-4'],
        },
        {
            id: 'Azerbaijan Standard Time',
            abbr: 'ADT',
            offset: 5,
            isdst: true,
            name: '(UTC+04:00) Baku',
            utc: ['Asia/Baku'],
        },
        {
            id: 'Mauritius Standard Time',
            abbr: 'MST',
            offset: 4,
            isdst: false,
            name: '(UTC+04:00) Port Louis',
            utc: ['Indian/Mahe', 'Indian/Mauritius', 'Indian/Reunion'],
        },
        {
            id: 'Georgian Standard Time',
            abbr: 'GET',
            offset: 4,
            isdst: false,
            name: '(UTC+04:00) Tbilisi',
            utc: ['Asia/Tbilisi'],
        },
        {
            id: 'Caucasus Standard Time',
            abbr: 'CST',
            offset: 4,
            isdst: false,
            name: '(UTC+04:00) Yerevan',
            utc: ['Asia/Yerevan'],
        },
        {
            id: 'Afghanistan Standard Time',
            abbr: 'AST',
            offset: 4.5,
            isdst: false,
            name: '(UTC+04:30) Kabul',
            utc: ['Asia/Kabul'],
        },
        {
            id: 'West Asia Standard Time',
            abbr: 'WAST',
            offset: 5,
            isdst: false,
            name: '(UTC+05:00) Ashgabat, Tashkent',
            utc: [
                'Antarctica/Mawson',
                'Asia/Aqtau',
                'Asia/Aqtobe',
                'Asia/Ashgabat',
                'Asia/Dushanbe',
                'Asia/Oral',
                'Asia/Samarkand',
                'Asia/Tashkent',
                'Etc/GMT-5',
                'Indian/Kerguelen',
                'Indian/Maldives',
            ],
        },
        {
            id: 'Yekaterinburg Time',
            abbr: 'YEKT',
            offset: 5,
            isdst: false,
            name: '(UTC+05:00) Yekaterinburg',
            utc: ['Asia/Yekaterinburg'],
        },
        {
            id: 'Pakistan Standard Time',
            abbr: 'PKT',
            offset: 5,
            isdst: false,
            name: '(UTC+05:00) Islamabad, Karachi',
            utc: ['Asia/Karachi'],
        },
        {
            id: 'India Standard Time',
            abbr: 'IST',
            offset: 5.5,
            isdst: false,
            name: '(UTC+05:30) Chennai, Kolkata, Mumbai, New Delhi',
            utc: ['Asia/Kolkata'],
        },
        {
            id: 'Sri Lanka Standard Time',
            abbr: 'SLST',
            offset: 5.5,
            isdst: false,
            name: '(UTC+05:30) Sri Jayawardenepura',
            utc: ['Asia/Colombo'],
        },
        {
            id: 'Nepal Standard Time',
            abbr: 'NST',
            offset: 5.75,
            isdst: false,
            name: '(UTC+05:45) Kathmandu',
            utc: ['Asia/Kathmandu'],
        },
        {
            id: 'Central Asia Standard Time',
            abbr: 'CAST',
            offset: 6,
            isdst: false,
            name: '(UTC+06:00) Astana',
            utc: [
                'Antarctica/Vostok',
                'Asia/Almaty',
                'Asia/Bishkek',
                'Asia/Qyzylorda',
                'Asia/Urumqi',
                'Etc/GMT-6',
                'Indian/Chagos',
            ],
        },
        {
            id: 'Bangladesh Standard Time',
            abbr: 'BST',
            offset: 6,
            isdst: false,
            name: '(UTC+06:00) Dhaka',
            utc: ['Asia/Dhaka', 'Asia/Thimphu'],
        },
        {
            id: 'Myanmar Standard Time',
            abbr: 'MST',
            offset: 6.5,
            isdst: false,
            name: '(UTC+06:30) Yangon (Rangoon)',
            utc: ['Asia/Rangoon', 'Indian/Cocos'],
        },
        {
            id: 'SE Asia Standard Time',
            abbr: 'SAST',
            offset: 7,
            isdst: false,
            name: '(UTC+07:00) Bangkok, Hanoi, Jakarta',
            utc: [
                'Antarctica/Davis',
                'Asia/Bangkok',
                'Asia/Hovd',
                'Asia/Jakarta',
                'Asia/Phnom_Penh',
                'Asia/Pontianak',
                'Asia/Saigon',
                'Asia/Vientiane',
                'Etc/GMT-7',
                'Indian/Christmas',
            ],
        },
        {
            id: 'N. Central Asia Standard Time',
            abbr: 'NCAST',
            offset: 7,
            isdst: false,
            name: '(UTC+07:00) Novosibirsk',
            utc: ['Asia/Novokuznetsk', 'Asia/Novosibirsk', 'Asia/Omsk'],
        },
        {
            id: 'China Standard Time',
            abbr: 'CST',
            offset: 8,
            isdst: false,
            name: '(UTC+08:00) Beijing, Chongqing, Hong Kong, Urumqi',
            utc: ['Asia/Hong_Kong', 'Asia/Macau', 'Asia/Shanghai'],
        },
        {
            id: 'North Asia Standard Time',
            abbr: 'NAST',
            offset: 8,
            isdst: false,
            name: '(UTC+08:00) Krasnoyarsk',
            utc: ['Asia/Krasnoyarsk'],
        },
        {
            id: 'Singapore Standard Time',
            abbr: 'MPST',
            offset: 8,
            isdst: false,
            name: '(UTC+08:00) Kuala Lumpur, Singapore',
            utc: [
                'Asia/Brunei',
                'Asia/Kuala_Lumpur',
                'Asia/Kuching',
                'Asia/Makassar',
                'Asia/Manila',
                'Asia/Singapore',
                'Etc/GMT-8',
            ],
        },
        {
            id: 'W. Australia Standard Time',
            abbr: 'WAST',
            offset: 8,
            isdst: false,
            name: '(UTC+08:00) Perth',
            utc: ['Antarctica/Casey', 'Australia/Perth'],
        },
        {
            id: 'Taipei Standard Time',
            abbr: 'TST',
            offset: 8,
            isdst: false,
            name: '(UTC+08:00) Taipei',
            utc: ['Asia/Taipei'],
        },
        {
            id: 'Ulaanbaatar Standard Time',
            abbr: 'UST',
            offset: 8,
            isdst: false,
            name: '(UTC+08:00) Ulaanbaatar',
            utc: ['Asia/Choibalsan', 'Asia/Ulaanbaatar'],
        },
        {
            id: 'North Asia East Standard Time',
            abbr: 'NAEST',
            offset: 8,
            isdst: false,
            name: '(UTC+08:00) Irkutsk',
            utc: ['Asia/Irkutsk'],
        },
        {
            id: 'Japan Standard Time',
            abbr: 'JST',
            offset: 9,
            isdst: false,
            name: '(UTC+09:00) Osaka, Sapporo, Tokyo',
            utc: [
                'Asia/Dili',
                'Asia/Jayapura',
                'Asia/Tokyo',
                'Etc/GMT-9',
                'Pacific/Palau',
            ],
        },
        {
            id: 'Korea Standard Time',
            abbr: 'KST',
            offset: 9,
            isdst: false,
            name: '(UTC+09:00) Seoul',
            utc: ['Asia/Pyongyang', 'Asia/Seoul'],
        },
        {
            id: 'Cen. Australia Standard Time',
            abbr: 'CAST',
            offset: 9.5,
            isdst: false,
            name: '(UTC+09:30) Adelaide',
            utc: ['Australia/Adelaide', 'Australia/Broken_Hill'],
        },
        {
            id: 'AUS Central Standard Time',
            abbr: 'ACST',
            offset: 9.5,
            isdst: false,
            name: '(UTC+09:30) Darwin',
            utc: ['Australia/Darwin'],
        },
        {
            id: 'E. Australia Standard Time',
            abbr: 'EAST',
            offset: 10,
            isdst: false,
            name: '(UTC+10:00) Brisbane',
            utc: ['Australia/Brisbane', 'Australia/Lindeman'],
        },
        {
            id: 'AUS Eastern Standard Time',
            abbr: 'AEST',
            offset: 10,
            isdst: false,
            name: '(UTC+10:00) Canberra, Melbourne, Sydney',
            utc: ['Australia/Melbourne', 'Australia/Sydney'],
        },
        {
            id: 'West Pacific Standard Time',
            abbr: 'WPST',
            offset: 10,
            isdst: false,
            name: '(UTC+10:00) Guam, Port Moresby',
            utc: [
                'Antarctica/DumontDUrville',
                'Etc/GMT-10',
                'Pacific/Guam',
                'Pacific/Port_Moresby',
                'Pacific/Saipan',
                'Pacific/Truk',
            ],
        },
        {
            id: 'Tasmania Standard Time',
            abbr: 'TST',
            offset: 10,
            isdst: false,
            name: '(UTC+10:00) Hobart',
            utc: ['Australia/Currie', 'Australia/Hobart'],
        },
        {
            id: 'Yakutsk Standard Time',
            abbr: 'YST',
            offset: 9,
            isdst: false,
            name: '(UTC+09:00) Yakutsk',
            utc: ['Asia/Chita', 'Asia/Khandyga', 'Asia/Yakutsk'],
        },
        {
            id: 'Central Pacific Standard Time',
            abbr: 'CPST',
            offset: 11,
            isdst: false,
            name: '(UTC+11:00) Solomon Is., New Caledonia',
            utc: [
                'Antarctica/Macquarie',
                'Etc/GMT-11',
                'Pacific/Efate',
                'Pacific/Guadalcanal',
                'Pacific/Kosrae',
                'Pacific/Noumea',
                'Pacific/Ponape',
            ],
        },
        {
            id: 'Vladivostok Standard Time',
            abbr: 'VST',
            offset: 11,
            isdst: false,
            name: '(UTC+11:00) Vladivostok',
            utc: ['Asia/Sakhalin', 'Asia/Ust-Nera', 'Asia/Vladivostok'],
        },
        {
            id: 'New Zealand Standard Time',
            abbr: 'NZST',
            offset: 12,
            isdst: false,
            name: '(UTC+12:00) Auckland, Wellington',
            utc: ['Antarctica/McMurdo', 'Pacific/Auckland'],
        },
        {
            id: 'UTC+12',
            abbr: 'U',
            offset: 12,
            isdst: false,
            name: '(UTC+12:00) Coordinated Universal Time+12',
            utc: [
                'Etc/GMT-12',
                'Pacific/Funafuti',
                'Pacific/Kwajalein',
                'Pacific/Majuro',
                'Pacific/Nauru',
                'Pacific/Tarawa',
                'Pacific/Wake',
                'Pacific/Wallis',
            ],
        },
        {
            id: 'Fiji Standard Time',
            abbr: 'FST',
            offset: 12,
            isdst: false,
            name: '(UTC+12:00) Fiji',
            utc: ['Pacific/Fiji'],
        },
        {
            id: 'Magadan Standard Time',
            abbr: 'MST',
            offset: 12,
            isdst: false,
            name: '(UTC+12:00) Magadan',
            utc: [
                'Asia/Anadyr',
                'Asia/Kamchatka',
                'Asia/Magadan',
                'Asia/Srednekolymsk',
            ],
        },
        {
            id: 'Kamchatka Standard Time',
            abbr: 'KDT',
            offset: 13,
            isdst: true,
            name: '(UTC+12:00) Petropavlovsk-Kamchatsky - Old',
            utc: ['Asia/Kamchatka'],
        },
        {
            id: 'Tonga Standard Time',
            abbr: 'TST',
            offset: 13,
            isdst: false,
            name: "(UTC+13:00) Nuku'alofa",
            utc: [
                'Etc/GMT-13',
                'Pacific/Enderbury',
                'Pacific/Fakaofo',
                'Pacific/Tongatapu',
            ],
        },
        {
            id: 'Samoa Standard Time',
            abbr: 'SST',
            offset: 13,
            isdst: false,
            name: '(UTC+13:00) Samoa',
            utc: ['Pacific/Apia'],
        },
    ];
}
export function getCurrencies() {
    return [
        {
            id: 'AED',
            name: 'UAE Dirham',
            fractionSize: 2,
            symbol: {
                grapheme: '.د.إ',
                template: '1 $',
                rtl: true,
            },
            uniqSymbol: null,
        },
        {
            id: 'AFN',
            name: 'Afghani',
            fractionSize: 2,
            symbol: {
                grapheme: '؋',
                template: '1 $',
                rtl: true,
            },
            uniqSymbol: {
                grapheme: '؋',
                template: '1 $',
                rtl: true,
            },
        },
        {
            id: 'ALL',
            name: 'Lek',
            fractionSize: 2,
            symbol: {
                grapheme: 'L',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'Lek',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'AMD',
            name: 'Armenian Dram',
            fractionSize: 2,
            symbol: {
                grapheme: 'դր.',
                template: '1 $',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'դր.',
                template: '1 $',
                rtl: false,
            },
        },
        {
            id: 'ANG',
            name: 'Netherlands Antillean Guilder',
            fractionSize: 2,
            symbol: {
                grapheme: 'ƒ',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'NAƒ',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'AOA',
            name: 'Kwanza',
            fractionSize: 2,
            symbol: null,
            uniqSymbol: null,
        },
        {
            id: 'ARS',
            name: 'Argentine Peso',
            fractionSize: 2,
            symbol: {
                grapheme: '$',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: null,
        },
        {
            id: 'AUD',
            name: 'Australian Dollar',
            fractionSize: 2,
            symbol: {
                grapheme: '$',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'A$',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'AWG',
            name: 'Aruban Florin',
            fractionSize: 2,
            symbol: {
                grapheme: 'ƒ',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'Afl',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'AZN',
            name: 'Azerbaijanian Manat',
            fractionSize: 2,
            symbol: {
                grapheme: '₼',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: '₼',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'BAM',
            name: 'Convertible Mark',
            fractionSize: 2,
            symbol: {
                grapheme: 'KM',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'KM',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'BBD',
            name: 'Barbados Dollar',
            fractionSize: 2,
            symbol: {
                grapheme: '$',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: null,
        },
        {
            id: 'BDT',
            name: 'Taka',
            fractionSize: 2,
            symbol: null,
            uniqSymbol: null,
        },
        {
            id: 'BGN',
            name: 'Bulgarian Lev',
            fractionSize: 2,
            symbol: {
                grapheme: 'лв',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'лв',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'BHD',
            name: 'Bahraini Dinar',
            fractionSize: 3,
            symbol: {
                grapheme: '.د.ب',
                template: '1 $',
                rtl: true,
            },
            uniqSymbol: {
                grapheme: '.د.ب',
                template: '1 $',
                rtl: true,
            },
        },
        {
            id: 'BIF',
            name: 'Burundi Franc',
            fractionSize: 0,
            symbol: null,
            uniqSymbol: null,
        },
        {
            id: 'BMD',
            name: 'Bermudian Dollar',
            fractionSize: 2,
            symbol: {
                grapheme: '$',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'BD$',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'BND',
            name: 'Brunei Dollar',
            fractionSize: 2,
            symbol: {
                grapheme: '$',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: null,
        },
        {
            id: 'BOB',
            name: 'Boliviano',
            fractionSize: 2,
            symbol: {
                grapheme: 'Bs.',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'Bs.',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'BOV',
            name: 'Mvdol',
            fractionSize: 2,
            symbol: null,
            uniqSymbol: null,
        },
        {
            id: 'BRL',
            name: 'Brazilian Real',
            fractionSize: 2,
            symbol: {
                grapheme: 'R$',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'R$',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'BSD',
            name: 'Bahamian Dollar',
            fractionSize: 2,
            symbol: {
                grapheme: '$',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: null,
        },
        {
            id: 'BTN',
            name: 'Ngultrum',
            fractionSize: 2,
            symbol: null,
            uniqSymbol: null,
        },
        {
            id: 'BWP',
            name: 'Pula',
            fractionSize: 2,
            symbol: {
                grapheme: 'P',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'P',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'BYN',
            name: 'Belarussian Ruble',
            fractionSize: 2,
            symbol: {
                grapheme: 'p.',
                template: '1 $',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'р.',
                template: '1 $',
                rtl: false,
            },
        },
        {
            id: 'BYR',
            name: 'Belarussian Ruble',
            fractionSize: 0,
            symbol: {
                grapheme: 'p.',
                template: '1 $',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'р.',
                template: '1 $',
                rtl: false,
            },
        },
        {
            id: 'BZD',
            name: 'Belize Dollar',
            fractionSize: 2,
            symbol: {
                grapheme: 'BZ$',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'BZ$',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'CAD',
            name: 'Canadian Dollar',
            fractionSize: 2,
            symbol: {
                grapheme: '$',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'CA$',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'CDF',
            name: 'Congolese Franc',
            fractionSize: 2,
            symbol: null,
            uniqSymbol: null,
        },
        {
            id: 'CHE',
            name: 'WIR Euro',
            fractionSize: 2,
            symbol: null,
            uniqSymbol: null,
        },
        {
            id: 'CHF',
            name: 'Swiss Franc',
            fractionSize: 2,
            symbol: null,
            uniqSymbol: null,
        },
        {
            id: 'CHW',
            name: 'WIR Franc',
            fractionSize: 2,
            symbol: null,
            uniqSymbol: null,
        },
        {
            id: 'CLF',
            name: 'Unidad de Fomento',
            fractionSize: 4,
            symbol: null,
            uniqSymbol: null,
        },
        {
            id: 'CLP',
            name: 'Chilean Peso',
            fractionSize: 0,
            symbol: {
                grapheme: '$',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: null,
        },
        {
            id: 'CNY',
            name: 'Yuan Renminbi',
            fractionSize: 2,
            symbol: {
                grapheme: '元',
                template: '1 $',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: '元',
                template: '1 $',
                rtl: false,
            },
        },
        {
            id: 'COP',
            name: 'Colombian Peso',
            fractionSize: 0,
            symbol: {
                grapheme: '$',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: null,
        },
        {
            id: 'COU',
            name: 'Unidad de Valor Real',
            fractionSize: 2,
            symbol: null,
            uniqSymbol: null,
        },
        {
            id: 'CRC',
            name: 'Cost Rican Colon',
            fractionSize: 2,
            symbol: {
                grapheme: '₡',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: '₡',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'CUC',
            name: 'Peso Convertible',
            fractionSize: 2,
            symbol: null,
            uniqSymbol: null,
        },
        {
            id: 'CUP',
            name: 'Cuban Peso',
            fractionSize: 2,
            symbol: {
                grapheme: '$MN',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: '$MN',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'CVE',
            name: 'Cabo Verde Escudo',
            fractionSize: 2,
            symbol: null,
            uniqSymbol: null,
        },
        {
            id: 'CZK',
            name: 'Czech Koruna',
            fractionSize: 2,
            symbol: {
                grapheme: 'Kč',
                template: '1 $',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'Kč',
                template: '1 $',
                rtl: false,
            },
        },
        {
            id: 'DJF',
            name: 'Djibouti Franc',
            fractionSize: 0,
            symbol: null,
            uniqSymbol: null,
        },
        {
            id: 'DKK',
            name: 'Danish Krone',
            fractionSize: 2,
            symbol: {
                grapheme: 'kr',
                template: '1 $',
                rtl: false,
            },
            uniqSymbol: null,
        },
        {
            id: 'DOP',
            name: 'Dominican Peso',
            fractionSize: 2,
            symbol: {
                grapheme: 'RD$',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'RD$',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'DZD',
            name: 'Algerian Dinar',
            fractionSize: 2,
            symbol: {
                grapheme: '.د.ج',
                template: '1 $',
                rtl: true,
            },
            uniqSymbol: {
                grapheme: '.د.ج',
                template: '1 $',
                rtl: true,
            },
        },
        {
            id: 'EEK',
            name: 'Estonian Kroon',
            fractionSize: 2,
            symbol: {
                grapheme: 'kr',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: null,
        },
        {
            id: 'EGP',
            name: 'Egyptian Pound',
            fractionSize: 2,
            symbol: {
                grapheme: '£',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: '.ج.م',
                template: '1 $',
                rtl: true,
            },
        },
        {
            id: 'ERN',
            name: 'Nakfa',
            fractionSize: 2,
            symbol: null,
            uniqSymbol: null,
        },
        {
            id: 'ETB',
            name: 'Ethiopian Birr',
            fractionSize: 2,
            symbol: null,
            uniqSymbol: null,
        },
        {
            id: 'EUR',
            name: 'Euro',
            fractionSize: 2,
            symbol: {
                grapheme: '€',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: '€',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'FJD',
            name: 'Fiji Dollar',
            fractionSize: 2,
            symbol: {
                grapheme: '$',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'FJ$',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'FKP',
            name: 'Falkland Islands Pound',
            fractionSize: 2,
            symbol: {
                grapheme: '£',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: null,
        },
        {
            id: 'GBP',
            name: 'Pound Sterling',
            fractionSize: 2,
            symbol: {
                grapheme: '£',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: '£',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'GEL',
            name: 'Lari',
            fractionSize: 2,
            symbol: null,
            uniqSymbol: null,
        },
        {
            id: 'GGP',
            name: 'Guernsey Pound',
            fractionSize: 2,
            symbol: {
                grapheme: '£',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: null,
        },
        {
            id: 'GHC',
            name: 'Ghanaian Cedi',
            fractionSize: 2,
            symbol: {
                grapheme: '¢',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: '¢',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'GHS',
            name: 'Ghan Cedi',
            fractionSize: 2,
            symbol: null,
            uniqSymbol: null,
        },
        {
            id: 'GIP',
            name: 'Gibraltar Pound',
            fractionSize: 2,
            symbol: {
                grapheme: '£',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: null,
        },
        {
            id: 'GMD',
            name: 'Dalasi',
            fractionSize: 2,
            symbol: null,
            uniqSymbol: null,
        },
        {
            id: 'GNF',
            name: 'Guine Franc',
            fractionSize: 0,
            symbol: null,
            uniqSymbol: null,
        },
        {
            id: 'GTQ',
            name: 'Quetzal',
            fractionSize: 2,
            symbol: {
                grapheme: 'Q',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'Q',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'GYD',
            name: 'Guyan Dollar',
            fractionSize: 2,
            symbol: {
                grapheme: '$',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'GY$',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'HKD',
            name: 'Hong Kong Dollar',
            fractionSize: 2,
            symbol: {
                grapheme: '$',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'HK$',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'HNL',
            name: 'Lempira',
            fractionSize: 2,
            symbol: {
                grapheme: 'L',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'L',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'HRK',
            name: 'Croatian Kuna',
            fractionSize: 2,
            symbol: {
                grapheme: 'kn',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'kn',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'HTG',
            name: 'Gourde',
            fractionSize: 2,
            symbol: null,
            uniqSymbol: null,
        },
        {
            id: 'HUF',
            name: 'Forint',
            fractionSize: 0,
            symbol: {
                grapheme: 'Ft',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'Ft',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'IDR',
            name: 'Rupiah',
            fractionSize: 2,
            symbol: {
                grapheme: 'Rp',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'Rp',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'ILS',
            name: 'New Israeli Sheqel',
            fractionSize: 2,
            symbol: {
                grapheme: '₪',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: '₪',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'IMP',
            name: 'Manx Pound',
            fractionSize: 2,
            symbol: {
                grapheme: '£',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: null,
        },
        {
            id: 'INR',
            name: 'Indian Rupee',
            fractionSize: 2,
            symbol: {
                grapheme: '₹',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: '₹',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'IQD',
            name: 'Iraqi Dinar',
            fractionSize: 3,
            symbol: {
                grapheme: '.د.ع',
                template: '1 $',
                rtl: true,
            },
            uniqSymbol: {
                grapheme: '.د.ع',
                template: '1 $',
                rtl: true,
            },
        },
        {
            id: 'IRR',
            name: 'Iranian Rial',
            fractionSize: 0,
            symbol: {
                grapheme: '﷼',
                template: '1 $',
                rtl: true,
            },
            uniqSymbol: {
                grapheme: '﷼',
                template: '1 $',
                rtl: true,
            },
        },
        {
            id: 'ISK',
            name: 'Iceland Krona',
            fractionSize: 2,
            symbol: {
                grapheme: 'kr',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: null,
        },
        {
            id: 'JEP',
            name: 'Jersey Pound',
            fractionSize: 2,
            symbol: {
                grapheme: '£',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: null,
        },
        {
            id: 'JMD',
            name: 'Jamaican Dollar',
            fractionSize: 2,
            symbol: {
                grapheme: 'J$',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'J$',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'JOD',
            name: 'Jordanian Dinar',
            fractionSize: 3,
            symbol: {
                grapheme: '.د.إ',
                template: '1 $',
                rtl: true,
            },
            uniqSymbol: null,
        },
        {
            id: 'JPY',
            name: 'Yen',
            fractionSize: 0,
            symbol: {
                grapheme: '¥',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: '¥',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'KES',
            name: 'Kenyan Shilling',
            fractionSize: 2,
            symbol: {
                grapheme: 'KSh',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'KSh',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'KGS',
            name: 'Som',
            fractionSize: 2,
            symbol: {
                grapheme: 'сом',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'сом',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'KHR',
            name: 'Riel',
            fractionSize: 2,
            symbol: {
                grapheme: '៛',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: '៛',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'KMF',
            name: 'Comoro Franc',
            fractionSize: 0,
            symbol: null,
            uniqSymbol: null,
        },
        {
            id: 'KPW',
            name: 'North Korean Won',
            fractionSize: 0,
            symbol: {
                grapheme: '₩',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: null,
        },
        {
            id: 'KRW',
            name: 'Won',
            fractionSize: 0,
            symbol: {
                grapheme: '₩',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: '₩',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'KWD',
            name: 'Kuwaiti Dinar',
            fractionSize: 3,
            symbol: {
                grapheme: '.د.ك',
                template: '1 $',
                rtl: true,
            },
            uniqSymbol: {
                grapheme: '.د.ك',
                template: '1 $',
                rtl: true,
            },
        },
        {
            id: 'KYD',
            name: 'Cayman Islands Dollar',
            fractionSize: 2,
            symbol: {
                grapheme: '$',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'CI$',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'KZT',
            name: 'Tenge',
            fractionSize: 2,
            symbol: {
                grapheme: '₸',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: '₸',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'LAK',
            name: 'Kip',
            fractionSize: 2,
            symbol: {
                grapheme: '₭',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: '₭',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'LBP',
            name: 'Lebanese Pound',
            fractionSize: 2,
            symbol: {
                grapheme: '£',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: '.ل.ل',
                template: '1 $',
                rtl: true,
            },
        },
        {
            id: 'LKR',
            name: 'Sri Lank Rupee',
            fractionSize: 2,
            symbol: {
                grapheme: '₨',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: null,
        },
        {
            id: 'LRD',
            name: 'Liberian Dollar',
            fractionSize: 2,
            symbol: {
                grapheme: '$',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'L$',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'LSL',
            name: 'Loti',
            fractionSize: 2,
            symbol: null,
            uniqSymbol: null,
        },
        {
            id: 'LTL',
            name: 'Lithuanian Litas',
            fractionSize: 2,
            symbol: {
                grapheme: 'Lt',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'Lt',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'LVL',
            name: 'Latvian Lats',
            fractionSize: 2,
            symbol: {
                grapheme: 'Ls',
                template: '1 $',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'Ls',
                template: '1 $',
                rtl: false,
            },
        },
        {
            id: 'LYD',
            name: 'Libyan Dinar',
            fractionSize: 3,
            symbol: {
                grapheme: '.د.ل',
                template: '1 $',
                rtl: true,
            },
            uniqSymbol: {
                grapheme: '.د.ل',
                template: '1 $',
                rtl: true,
            },
        },
        {
            id: 'MAD',
            name: 'Moroccan Dirham',
            fractionSize: 2,
            symbol: {
                grapheme: '.د.م',
                template: '1 $',
                rtl: true,
            },
            uniqSymbol: {
                grapheme: '.د.م',
                template: '1 $',
                rtl: true,
            },
        },
        {
            id: 'MDL',
            name: 'Moldovan Leu',
            fractionSize: 2,
            symbol: null,
            uniqSymbol: null,
        },
        {
            id: 'MGA',
            name: 'Malagasy ariary',
            fractionSize: 1,
            symbol: null,
            uniqSymbol: null,
        },
        {
            id: 'MKD',
            name: 'Denar',
            fractionSize: 2,
            symbol: {
                grapheme: 'ден',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'ден',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'MMK',
            name: 'Kyat',
            fractionSize: 2,
            symbol: null,
            uniqSymbol: null,
        },
        {
            id: 'MNT',
            name: 'Tugrik',
            fractionSize: 2,
            symbol: {
                grapheme: '₮',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: '₮',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'MOP',
            name: 'Pataca',
            fractionSize: 2,
            symbol: null,
            uniqSymbol: null,
        },
        {
            id: 'MRO',
            name: 'Ouguiya',
            fractionSize: 2,
            symbol: null,
            uniqSymbol: null,
        },
        {
            id: 'MUR',
            name: 'Mauritius Rupee',
            fractionSize: 2,
            symbol: {
                grapheme: '₨',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: null,
        },
        {
            id: 'MVR',
            name: 'Rufiyaa',
            fractionSize: 2,
            symbol: null,
            uniqSymbol: null,
        },
        {
            id: 'MWK',
            name: 'Kwacha',
            fractionSize: 2,
            symbol: null,
            uniqSymbol: null,
        },
        {
            id: 'MXN',
            name: 'Mexican Peso',
            fractionSize: 2,
            symbol: {
                grapheme: '$',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: null,
        },
        {
            id: 'MXV',
            name: 'Mexican Unidad de Inversion (UDI)',
            fractionSize: 2,
            symbol: null,
            uniqSymbol: null,
        },
        {
            id: 'MYR',
            name: 'Malaysian Ringgit',
            fractionSize: 2,
            symbol: {
                grapheme: 'RM',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'RM',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'MZN',
            name: 'Mozambique Metical',
            fractionSize: 2,
            symbol: {
                grapheme: 'MT',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'MT',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'NAD',
            name: 'Namibi Dollar',
            fractionSize: 2,
            symbol: {
                grapheme: '$',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'N$',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'NGN',
            name: 'Naira',
            fractionSize: 2,
            symbol: {
                grapheme: '₦',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: '₦',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'NIO',
            name: 'Cordob Oro',
            fractionSize: 2,
            symbol: {
                grapheme: 'C$',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'C$',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'NOK',
            name: 'Norwegian Krone',
            fractionSize: 2,
            symbol: {
                grapheme: 'kr',
                template: '1 $',
                rtl: false,
            },
            uniqSymbol: null,
        },
        {
            id: 'NPR',
            name: 'Nepalese Rupee',
            fractionSize: 2,
            symbol: {
                grapheme: '₨',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: null,
        },
        {
            id: 'NZD',
            name: 'New Zealand Dollar',
            fractionSize: 2,
            symbol: {
                grapheme: '$',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'NZ$',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'OMR',
            name: 'Rial Omani',
            fractionSize: 3,
            symbol: {
                grapheme: '﷼',
                template: '1 $',
                rtl: true,
            },
            uniqSymbol: {
                grapheme: '.ر.ع',
                template: '1 $',
                rtl: true,
            },
        },
        {
            id: 'PAB',
            name: 'Balboa',
            fractionSize: 2,
            symbol: {
                grapheme: 'B/.',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'B/.',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'PEN',
            name: 'Nuevo Sol',
            fractionSize: 2,
            symbol: {
                grapheme: 'S/',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'S/',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'PGK',
            name: 'Kina',
            fractionSize: 2,
            symbol: null,
            uniqSymbol: null,
        },
        {
            id: 'PHP',
            name: 'Philippine Peso',
            fractionSize: 2,
            symbol: {
                grapheme: '₱',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: '₱',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'PKR',
            name: 'Pakistan Rupee',
            fractionSize: 2,
            symbol: {
                grapheme: '₨',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: null,
        },
        {
            id: 'PLN',
            name: 'Zloty',
            fractionSize: 2,
            symbol: {
                grapheme: 'zł',
                template: '1 $',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'zł',
                template: '1 $',
                rtl: false,
            },
        },
        {
            id: 'PYG',
            name: 'Guarani',
            fractionSize: 0,
            symbol: {
                grapheme: 'Gs',
                template: '1$',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'Gs',
                template: '1$',
                rtl: false,
            },
        },
        {
            id: 'QAR',
            name: 'Qatari Rial',
            fractionSize: 2,
            symbol: {
                grapheme: '﷼',
                template: '1 $',
                rtl: true,
            },
            uniqSymbol: {
                grapheme: '.ر.ق',
                template: '1 $',
                rtl: true,
            },
        },
        {
            id: 'RON',
            name: 'New Romanian Leu',
            fractionSize: 2,
            symbol: {
                grapheme: 'lei',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'lei',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'RSD',
            name: 'Serbian Dinar',
            fractionSize: 2,
            symbol: {
                grapheme: 'Дин.',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'Дин.',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'RUB',
            name: 'Russian Ruble',
            fractionSize: 2,
            symbol: {
                grapheme: '₽',
                template: '1 $',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: '₽',
                template: '1 $',
                rtl: false,
            },
        },
        {
            id: 'RUR',
            name: 'Russian Ruble',
            fractionSize: 2,
            symbol: {
                grapheme: '₽',
                template: '1 $',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: '₽',
                template: '1 $',
                rtl: false,
            },
        },
        {
            id: 'RWF',
            name: 'Rwand Franc',
            fractionSize: 0,
            symbol: null,
            uniqSymbol: null,
        },
        {
            id: 'SAR',
            name: 'Saudi Riyal',
            fractionSize: 2,
            symbol: {
                grapheme: '﷼',
                template: '1 $',
                rtl: true,
            },
            uniqSymbol: {
                grapheme: '.ر.س',
                template: '1 $',
                rtl: true,
            },
        },
        {
            id: 'SBD',
            name: 'Solomon Islands Dollar',
            fractionSize: 2,
            symbol: {
                grapheme: '$',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'SI$',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'SCR',
            name: 'Seychelles Rupee',
            fractionSize: 2,
            symbol: {
                grapheme: '₨',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: null,
        },
        {
            id: 'SDG',
            name: 'Sudanese Pound',
            fractionSize: 2,
            symbol: null,
            uniqSymbol: null,
        },
        {
            id: 'SEK',
            name: 'Swedish Krona',
            fractionSize: 2,
            symbol: {
                grapheme: 'kr',
                template: '1 $',
                rtl: false,
            },
            uniqSymbol: null,
        },
        {
            id: 'SGD',
            name: 'Singapore Dollar',
            fractionSize: 2,
            symbol: {
                grapheme: '$',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'S$',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'SHP',
            name: 'Saint Helen Pound',
            fractionSize: 2,
            symbol: {
                grapheme: '£',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: null,
        },
        {
            id: 'SLL',
            name: 'Leone',
            fractionSize: 2,
            symbol: null,
            uniqSymbol: null,
        },
        {
            id: 'SOS',
            name: 'Somali Shilling',
            fractionSize: 2,
            symbol: {
                grapheme: 'S',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'S',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'SRD',
            name: 'Surinam Dollar',
            fractionSize: 2,
            symbol: {
                grapheme: '$',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: null,
        },
        {
            id: 'SSP',
            name: 'South Sudanese Pound',
            fractionSize: 2,
            symbol: null,
            uniqSymbol: null,
        },
        {
            id: 'STD',
            name: 'Dobra',
            fractionSize: 2,
            symbol: null,
            uniqSymbol: null,
        },
        {
            id: 'SVC',
            name: 'El Salvador Colon',
            fractionSize: 2,
            symbol: {
                grapheme: '$',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'C',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'SYP',
            name: 'Syrian Pound',
            fractionSize: 2,
            symbol: {
                grapheme: '£',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: '.ل.س',
                template: '1 $',
                rtl: true,
            },
        },
        {
            id: 'SZL',
            name: 'Lilangeni',
            fractionSize: 2,
            symbol: null,
            uniqSymbol: null,
        },
        {
            id: 'THB',
            name: 'Baht',
            fractionSize: 2,
            symbol: {
                grapheme: '฿',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: '฿',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'TJS',
            name: 'Somoni',
            fractionSize: 2,
            symbol: null,
            uniqSymbol: null,
        },
        {
            id: 'TMT',
            name: 'Turkmenistan New Manat',
            fractionSize: 2,
            symbol: null,
            uniqSymbol: null,
        },
        {
            id: 'TND',
            name: 'Tunisian Dinar',
            fractionSize: 3,
            symbol: {
                grapheme: '.د.ت',
                template: '1 $',
                rtl: true,
            },
            uniqSymbol: {
                grapheme: '.د.ت',
                template: '1 $',
                rtl: true,
            },
        },
        {
            id: 'TOP',
            name: 'Pa’anga',
            fractionSize: 2,
            symbol: null,
            uniqSymbol: null,
        },
        {
            id: 'TRL',
            name: 'Turkish Lira',
            fractionSize: 2,
            symbol: {
                grapheme: '₤',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: null,
        },
        {
            id: 'TRY',
            name: 'Turkish Lira',
            fractionSize: 2,
            symbol: {
                grapheme: '₺',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: '₺',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'TTD',
            name: 'Trinidad and Tobago Dollar',
            fractionSize: 2,
            symbol: {
                grapheme: 'TT$',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'TT$',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'TWD',
            name: 'New Taiwan Dollar',
            fractionSize: 0,
            symbol: {
                grapheme: 'NT$',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'NT$',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'TZS',
            name: 'Tanzanian Shilling',
            fractionSize: 0,
            symbol: {
                grapheme: 'TSh',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'TSh',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'UAH',
            name: 'Hryvnia',
            fractionSize: 2,
            symbol: {
                grapheme: '₴',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: '₴',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'UGX',
            name: 'Ugand Shilling',
            fractionSize: 0,
            symbol: {
                grapheme: 'USh',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'USh',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'USD',
            name: 'US Dollar',
            fractionSize: 2,
            symbol: {
                grapheme: '$',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: '$',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'USN',
            name: 'US Dollar (Next day)',
            fractionSize: 2,
            symbol: null,
            uniqSymbol: null,
        },
        {
            id: 'UYI',
            name: 'Uruguay Peso en Unidades Indexadas (URUIURUI)',
            fractionSize: 0,
            symbol: null,
            uniqSymbol: null,
        },
        {
            id: 'UYU',
            name: 'Peso Uruguayo',
            fractionSize: 0,
            symbol: {
                grapheme: '$U',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: '$U',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'UZS',
            name: 'Uzbekistan Sum',
            fractionSize: 2,
            symbol: {
                grapheme: 'so’m',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'so’m',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'VEF',
            name: 'Bolivar',
            fractionSize: 2,
            symbol: {
                grapheme: 'Bs',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'Bs',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'VES',
            name: 'Bolivar',
            fractionSize: 2,
            symbol: {
                grapheme: 'Bs',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'Bs',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'VND',
            name: 'Dong',
            fractionSize: 0,
            symbol: {
                grapheme: '₫',
                template: '1 $',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: '₫',
                template: '1 $',
                rtl: false,
            },
        },
        {
            id: 'VUV',
            name: 'Vatu',
            fractionSize: 0,
            symbol: null,
            uniqSymbol: null,
        },
        {
            id: 'WST',
            name: 'Tala',
            fractionSize: 2,
            symbol: null,
            uniqSymbol: null,
        },
        {
            id: 'XAF',
            name: 'CFA Franc BEAC',
            fractionSize: 0,
            symbol: {
                grapheme: 'FCFA',
                template: '1 $',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'FCFA',
                template: '1 $',
                rtl: false,
            },
        },
        {
            id: 'XCD',
            name: 'East Caribbean Dollar',
            fractionSize: 2,
            symbol: {
                grapheme: '$',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'EC$',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'XDR',
            name: 'SDR (Special Drawing Right)',
            fractionSize: 0,
            symbol: null,
            uniqSymbol: null,
        },
        {
            id: 'XOF',
            name: 'CFA Franc BCEAO',
            fractionSize: 0,
            symbol: {
                grapheme: 'CFA',
                template: '1 $',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'CFA',
                template: '1 $',
                rtl: false,
            },
        },
        {
            id: 'XPF',
            name: 'CFP Franc',
            fractionSize: 0,
            symbol: null,
            uniqSymbol: null,
        },
        {
            id: 'XSU',
            name: 'Sucre',
            fractionSize: 0,
            symbol: null,
            uniqSymbol: null,
        },
        {
            id: 'XUA',
            name: 'ADB Unit of Account',
            fractionSize: 0,
            symbol: null,
            uniqSymbol: null,
        },
        {
            id: 'YER',
            name: 'Yemeni Rial',
            fractionSize: 2,
            symbol: {
                grapheme: '﷼',
                template: '1 $',
                rtl: true,
            },
            uniqSymbol: {
                grapheme: '.ر.ي',
                template: '1 $',
                rtl: true,
            },
        },
        {
            id: 'ZAR',
            name: 'Rand',
            fractionSize: 2,
            symbol: {
                grapheme: 'R',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'R',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'ZMW',
            name: 'Zambian Kwacha',
            fractionSize: 2,
            symbol: null,
            uniqSymbol: null,
        },
        {
            id: 'ZWD',
            name: 'Zimbabwe Dollar',
            fractionSize: 2,
            symbol: {
                grapheme: 'Z$',
                template: '$1',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'Z$',
                template: '$1',
                rtl: false,
            },
        },
        {
            id: 'ZWL',
            name: 'Zimbabwe Dollar',
            fractionSize: 2,
            symbol: null,
            uniqSymbol: null,
        },
        {
            id: 'BTC',
            name: 'BTC',
            fractionSize: 4,
            symbol: {
                grapheme: '₿',
                template: '1 $',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: '₿',
                template: '1 $',
                rtl: false,
            },
        },
        {
            id: 'ETH',
            name: 'ETH',
            fractionSize: 4,
            symbol: {
                grapheme: 'Ξ',
                template: '1 $',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'Ξ',
                template: '1 $',
                rtl: false,
            },
        },
        {
            id: 'LTC',
            name: 'LTC',
            fractionSize: 4,
            symbol: {
                grapheme: 'Ł',
                template: '1 $',
                rtl: false,
            },
            uniqSymbol: {
                grapheme: 'Ł',
                template: '1 $',
                rtl: false,
            },
        },
    ];
}
//# sourceMappingURL=settings.js.map