import { getDateLocale } from '../../helpers/get-date-locale';
import { addMonths, addWeeks, addMinutes, addHours, subSeconds, subMinutes, subHours, subDays, subWeeks, subMonths, subQuarters, subYears, addDays, addQuarters, addYears, addSeconds, differenceInMinutes, differenceInHours, differenceInWeeks, differenceInQuarters, differenceInYears, startOfSecond, startOfWeek, startOfMonth, startOfYear, startOfHour, startOfMinute, differenceInSeconds, differenceInDays, differenceInMonths, startOfDay, startOfQuarter, endOfSecond, endOfMinute, endOfHour, endOfDay, endOfWeek, endOfMonth, endOfQuarter, endOfYear, getDay, getWeek, isSameMonth, isSameQuarter, isSameYear, isSameDay, isSameWeek, isWithinInterval, isAfter, isValid, getDaysInMonth, setDay, setSeconds, setMinutes, setHours, eachDayOfInterval, subMilliseconds, addMilliseconds, getYear, format, parse, differenceInMilliseconds, parseJSON, } from 'date-fns';
import getISOWeekYear from 'date-fns/getISOWeekYear';
import getISOWeek from 'date-fns/getISOWeek';
import getISODay from 'date-fns/getISODay';
import { mapTcDateFormatToDateFnsDateFormat } from '../../mappers';
var TcDate = /** @class */ (function () {
    function TcDate(date, format) {
        var _this = this;
        this.getWeekDates = function (weekStartDay) {
            var startOfWeekDate = startOfWeek(_this.date, {
                weekStartsOn: weekStartDay,
            });
            var weekDates = [];
            for (var i = 0; i < 7; i++) {
                weekDates.push(addDays(startOfWeekDate, i));
            }
            return weekDates;
        };
        this.getDayShortName = function (locale) {
            var dayShortName = _this.format('EEE d', locale);
            return dayShortName.charAt(0).toUpperCase() + dayShortName.slice(1);
        };
        this.getYearMonthDayKey = function () {
            return _this.format('yyyy-MM-dd');
        };
        this.getDateOfWeek = function (week, year) {
            var day = 1 + (week - 1) * 7;
            return new Date(year, 0, day);
        };
        this.getDateOfIsoWeek = function (week, year) {
            var simple = new Date(Date.UTC(year, 0, 1 + (week - 1) * 7));
            var dow = simple.getDay();
            var isoWeekStart = simple;
            if (dow <= 4) {
                isoWeekStart.setDate(simple.getDate() - simple.getDay() + 1);
            }
            else {
                isoWeekStart.setDate(simple.getDate() + 8 - simple.getDay());
            }
            return isoWeekStart;
        };
        this.getIsoWeekAndYear = function () {
            return {
                year: getISOWeekYear(_this.date),
                week: getISOWeek(_this.date),
                day: getISODay(_this.date),
            };
        };
        this.getISODay = function () {
            return getISODay(_this.date);
        };
        this.getISOYear = function () {
            return getISOWeekYear(_this.date);
        };
        this.getIsoWeek = function () {
            return getISOWeek(_this.date);
        };
        this.getDateWithoutTimeAsUTC = function () {
            if (!_this.date) {
                throw new Error('Date is null');
            }
            return new Date(Date.UTC(_this.date.getFullYear(), _this.date.getMonth(), _this.date.getDate(), 0, 0, 0, 0));
        };
        if (!date) {
            date = new Date();
        }
        if (typeof date === 'string') {
            if (format) {
                this.date = parse(date, format, new Date());
            }
            else {
                this.date = parseJSON(date);
            }
        }
        else {
            this.date = date;
        }
    }
    TcDate.prototype.toDate = function () {
        return this.date;
    };
    TcDate.prototype.format = function (template, locale) {
        if (locale === void 0) { locale = 'en'; }
        if (template === 'h:mma') {
            template = 'h:mmaaa';
        }
        var mappedTemplate = mapTcDateFormatToDateFnsDateFormat(template);
        return format(this.date, mappedTemplate, {
            locale: getDateLocale(locale),
        });
    };
    TcDate.prototype.add = function (amount, type) {
        var date;
        switch (type) {
            case 'milliseconds':
            case 'millisecond':
            case 'ms':
                date = addMilliseconds(this.date, amount);
                break;
            case 'seconds':
            case 'second':
            case 's':
                date = addSeconds(this.date, amount);
                break;
            case 'minutes':
            case 'minute':
            case 'm':
                date = addMinutes(this.date, amount);
                break;
            case 'hours':
            case 'hour':
            case 'h':
                date = addHours(this.date, amount);
                break;
            case 'days':
            case 'day':
            case 'd':
                date = addDays(this.date, amount);
                break;
            case 'weeks':
            case 'week':
            case 'w':
                date = addWeeks(this.date, amount);
                break;
            case 'months':
            case 'month':
            case 'M':
                date = addMonths(this.date, amount);
                break;
            case 'quarters':
            case 'quarter':
            case 'q':
                date = addQuarters(this.date, amount);
                break;
            case 'years':
            case 'year':
            case 'y':
                date = addYears(this.date, amount);
                break;
            default:
                throw new Error(type + " is not supported");
        }
        return new TcDate(date);
    };
    TcDate.prototype.subtract = function (amount, type) {
        var date;
        switch (type) {
            case 'milliseconds':
            case 'millisecond':
            case 'ms':
                date = subMilliseconds(this.date, amount);
                break;
            case 'seconds':
            case 'second':
            case 's':
                date = subSeconds(this.date, amount);
                break;
            case 'minutes':
            case 'minute':
            case 'm':
                date = subMinutes(this.date, amount);
                break;
            case 'hours':
            case 'hour':
            case 'h':
                date = subHours(this.date, amount);
                break;
            case 'days':
            case 'day':
            case 'd':
                date = subDays(this.date, amount);
                break;
            case 'weeks':
            case 'week':
            case 'w':
                date = subWeeks(this.date, amount);
                break;
            case 'months':
            case 'month':
            case 'M':
                date = subMonths(this.date, amount);
                break;
            case 'quarters':
            case 'quarter':
            case 'q':
                date = subQuarters(this.date, amount);
                break;
            case 'years':
            case 'year':
            case 'y':
                date = subYears(this.date, amount);
                break;
            default:
                throw new Error(type + " is not supported");
        }
        return new TcDate(date);
    };
    TcDate.prototype.diff = function (start, type) {
        var difference = differenceInSeconds(this.date, start);
        switch (type) {
            case 'milliseconds':
            case 'millisecond':
            case 'ms':
                difference = differenceInMilliseconds(this.date, start);
                break;
            case 'seconds':
            case 'second':
            case 's':
                difference = differenceInSeconds(this.date, start);
                break;
            case 'minutes':
            case 'minute':
            case 'm':
                difference = differenceInMinutes(this.date, start);
                break;
            case 'hours':
            case 'hour':
            case 'h':
                difference = differenceInHours(this.date, start);
                break;
            case 'days':
            case 'day':
            case 'd':
                difference = differenceInDays(this.date, start);
                break;
            case 'weeks':
            case 'week':
            case 'w':
                difference = differenceInWeeks(this.date, start);
                break;
            case 'months':
            case 'month':
            case 'M':
                difference = differenceInMonths(this.date, start);
                break;
            case 'quarters':
            case 'quarter':
            case 'q':
                difference = differenceInQuarters(this.date, start);
                break;
            case 'years':
            case 'year':
            case 'y':
                difference = differenceInYears(this.date, start);
                break;
            default:
                throw new Error(type + " is not supported");
        }
        return difference;
    };
    TcDate.prototype.startOf = function (type, weekStartDay) {
        var date;
        switch (type) {
            case 'seconds':
            case 'second':
            case 's':
                date = startOfSecond(this.date);
                break;
            case 'minutes':
            case 'minute':
            case 'm':
                date = startOfMinute(this.date);
                break;
            case 'hours':
            case 'hour':
            case 'h':
                date = startOfHour(this.date);
                break;
            case 'days':
            case 'day':
            case 'd':
                date = startOfDay(this.date);
                break;
            case 'weeks':
            case 'week':
            case 'w':
                date = startOfWeek(this.date, { weekStartsOn: weekStartDay });
                break;
            case 'months':
            case 'month':
            case 'M':
                date = startOfMonth(this.date);
                break;
            case 'quarters':
            case 'quarter':
            case 'q':
                date = startOfQuarter(this.date);
                break;
            case 'years':
            case 'year':
            case 'y':
                date = startOfYear(this.date);
                break;
            default:
                throw new Error(type + " is not supported");
        }
        return new TcDate(date);
    };
    TcDate.prototype.endOf = function (type, weekStartDay) {
        var date;
        switch (type) {
            case 'seconds':
            case 'second':
            case 's':
                date = endOfSecond(this.date);
                break;
            case 'minutes':
            case 'minute':
            case 'm':
                date = endOfMinute(this.date);
                break;
            case 'hours':
            case 'hour':
            case 'h':
                date = endOfHour(this.date);
                break;
            case 'days':
            case 'day':
            case 'd':
                date = endOfDay(this.date);
                break;
            case 'weeks':
            case 'week':
            case 'w':
                date = endOfWeek(this.date, { weekStartsOn: weekStartDay });
                break;
            case 'months':
            case 'month':
            case 'M':
                date = endOfMonth(this.date);
                break;
            case 'quarters':
            case 'quarter':
            case 'q':
                date = endOfQuarter(this.date);
                break;
            case 'years':
            case 'year':
            case 'y':
                date = endOfYear(this.date);
                break;
            default:
                throw new Error(type + " is not supported");
        }
        return new TcDate(date);
    };
    TcDate.prototype.weekday = function () {
        return getDay(this.date);
    };
    TcDate.prototype.weekdayToDate = function (day, weekStartDay) {
        return setDay(this.date, day, { weekStartsOn: weekStartDay });
    };
    TcDate.prototype.week = function (weekStartDay) {
        return getWeek(this.date, { weekStartsOn: weekStartDay });
    };
    TcDate.prototype.year = function () {
        return getYear(this.date);
    };
    TcDate.prototype.isSame = function (dateToCheck, type, weekStartDay) {
        switch (type) {
            case 'days':
            case 'day':
            case 'd':
                return isSameDay(this.date, dateToCheck);
            case 'weeks':
            case 'week':
            case 'w':
                return isSameWeek(this.date, dateToCheck, {
                    weekStartsOn: weekStartDay,
                });
            case 'months':
            case 'month':
            case 'M':
                return isSameMonth(this.date, dateToCheck);
            case 'quarters':
            case 'quarter':
            case 'q':
                return isSameQuarter(this.date, dateToCheck);
            case 'years':
            case 'year':
            case 'y':
                return isSameYear(this.date, dateToCheck);
            default:
                throw new Error(type + " is not supported");
        }
    };
    TcDate.prototype.isBetween = function (_a) {
        var start = _a.start, end = _a.end;
        return isWithinInterval(this.date, {
            start: start,
            end: end,
        });
    };
    TcDate.prototype.isAfter = function (dateToCheck) {
        return isAfter(this.date, dateToCheck);
    };
    TcDate.prototype.isValid = function () {
        return isValid(this.date);
    };
    TcDate.prototype.set = function (amount, type) {
        var date;
        switch (type) {
            case 'second':
            case 'seconds':
                date = setSeconds(this.date, amount);
                break;
            case 'minute':
            case 'minutes':
                date = setMinutes(this.date, amount);
                break;
            case 'hour':
            case 'hours':
                date = setHours(this.date, amount);
        }
        return new TcDate(date);
    };
    TcDate.prototype.daysInMonth = function () {
        return getDaysInMonth(this.date);
    };
    TcDate.prototype.toISOString = function () {
        return this.date.toISOString();
    };
    TcDate.prototype.interval = function (start, end) {
        return eachDayOfInterval({
            start: start,
            end: end,
        });
    };
    return TcDate;
}());
export { TcDate };
//# sourceMappingURL=date.js.map